@@ -2,7 +2,7 @@ package PDF::Tiny;
 
 use 5.01;
 
-$VERSION = '0.03'; # Update the POD, too!
+$VERSION = '0.04'; # Update the POD, too!
 
 # Fields
 sub vers () { 0 }
@@ -96,7 +96,7 @@ sub new {
 sub _parse_xref {
 	my($self) = shift;
 	my $fh = $self->[fh];
-	seek $fh, -1024,2;
+	seek $fh, -1024,2 or seek $fh, 0,0;
 	read $fh, my $read, 1024
 		or croak "Cannot read $self->[file]: $!", 1;
 	$read =~ /startxref$N(\d+)$N%%EOF$N?$/o;
